<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>AboutDialog</name>
    <message>
        <source>&amp;Close</source>
        <translation>關閉(&amp;C)</translation>
    </message>
</context>
<context>
    <name>AboutLabel</name>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>Unable to launch external application.</source>
        <translation>無法執行外部應用程式。</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>確定</translation>
    </message>
</context>
<context>
    <name>Assistant</name>
    <message>
        <source>Error registering documentation file &apos;%1&apos;: %2</source>
        <translation>註冊文件檔案「%1」發生問題：%2</translation>
    </message>
    <message>
        <source>Could not register documentation file
%1

Reason:
%2</source>
        <translation>無法註冊文件檔案
%1

理由：
%2</translation>
    </message>
    <message>
        <source>Documentation successfully registered.</source>
        <translation>文件註冊成功。</translation>
    </message>
    <message>
        <source>Could not unregister documentation file
%1

Reason:
%2</source>
        <translation>無法解除註冊文件檔案
%1

理由：
%2</translation>
    </message>
    <message>
        <source>Documentation successfully unregistered.</source>
        <translation>文件成功解除註冊。</translation>
    </message>
    <message>
        <source>Error reading collection file &apos;%1&apos;: %2.</source>
        <translation>讀取集合檔案「%1」發生錯誤：%2。</translation>
    </message>
    <message>
        <source>Error creating collection file &apos;%1&apos;: %2.</source>
        <translation>建立集合檔案「%1」發生錯誤：%2。</translation>
    </message>
    <message>
        <source>Cannot load sqlite database driver!</source>
        <translation>無法載入 sqlite 資料庫驅動程式！</translation>
    </message>
</context>
<context>
    <name>BookmarkDialog</name>
    <message>
        <source>Add Bookmark</source>
        <translation>新增書籤</translation>
    </message>
    <message>
        <source>Bookmark:</source>
        <translation>書籤：</translation>
    </message>
    <message>
        <source>Add in Folder:</source>
        <translation>新增到資料夾：</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>新增資料夾</translation>
    </message>
    <message>
        <source>Rename Folder</source>
        <translation>重命名資料夾</translation>
    </message>
</context>
<context>
    <name>BookmarkItem</name>
    <message>
        <source>New Folder</source>
        <translation>新資料夾</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>未命名</translation>
    </message>
</context>
<context>
    <name>BookmarkManager</name>
    <message>
        <source>Untitled</source>
        <translation>未命名</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <source>You are going to delete a Folder, this will also&lt;br&gt;remove it&apos;s content. Are you sure to continue?</source>
        <translation>您打算刪除資料夾，這會將裡面的內容&lt;br&gt;一併移除。您確定要繼續嗎？</translation>
    </message>
    <message>
        <source>Manage Bookmarks...</source>
        <translation>管理書籤…</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>新增書籤...</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation></translation>
    </message>
    <message>
        <source>Delete Folder</source>
        <translation>刪除資料夾</translation>
    </message>
    <message>
        <source>Rename Folder</source>
        <translation>重新命名資料夾</translation>
    </message>
    <message>
        <source>Show Bookmark</source>
        <translation>顯示書籤</translation>
    </message>
    <message>
        <source>Show Bookmark in New Tab</source>
        <translation>於新分頁顯示書籤</translation>
    </message>
    <message>
        <source>Delete Bookmark</source>
        <translation>刪除書籤</translation>
    </message>
    <message>
        <source>Rename Bookmark</source>
        <translation>重新命名書籤</translation>
    </message>
</context>
<context>
    <name>BookmarkManagerWidget</name>
    <message>
        <source>Manage Bookmarks</source>
        <translation>管理書籤</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation>搜尋：</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <source>Import and Backup</source>
        <translation>匯入與備份</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>確定</translation>
    </message>
    <message>
        <source>Import...</source>
        <translation>匯入…</translation>
    </message>
    <message>
        <source>Export...</source>
        <translation>匯出…</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>開啟檔案</translation>
    </message>
    <message>
        <source>Files (*.xbel)</source>
        <translation>檔案 (*.xbel)</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>儲存檔案</translation>
    </message>
    <message>
        <source>Qt Assistant</source>
        <translation>Qt 小幫手</translation>
    </message>
    <message>
        <source>Unable to save bookmarks.</source>
        <translation>無法儲存書籤。</translation>
    </message>
    <message>
        <source>You are goingto delete a Folder, this will also&lt;br&gt; remove it&apos;s content. Are you sure to continue?</source>
        <translation>您打算刪除一個資料夾，這將也會&lt;br&gt; 移除資料夾中內容，確定刪除？</translation>
    </message>
    <message>
        <source>Delete Folder</source>
        <translation>刪除資料夾</translation>
    </message>
    <message>
        <source>Rename Folder</source>
        <translation>重新命名資料夾</translation>
    </message>
    <message>
        <source>Show Bookmark</source>
        <translation>顯示書籤</translation>
    </message>
    <message>
        <source>Show Bookmark in New Tab</source>
        <translation>於新分頁顯示書籤</translation>
    </message>
    <message>
        <source>Delete Bookmark</source>
        <translation>刪除書籤</translation>
    </message>
    <message>
        <source>Rename Bookmark</source>
        <translation>重新命名書籤</translation>
    </message>
</context>
<context>
    <name>BookmarkModel</name>
    <message>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>位址</translation>
    </message>
    <message>
        <source>Bookmarks Toolbar</source>
        <translation>書籤工具列</translation>
    </message>
    <message>
        <source>Bookmarks Menu</source>
        <translation>書籤選單</translation>
    </message>
</context>
<context>
    <name>BookmarkWidget</name>
    <message>
        <source>Bookmarks</source>
        <translation>書籤</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>過濾：</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>新增</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
</context>
<context>
    <name>CentralWidget</name>
    <message>
        <source>Print Document</source>
        <translation>列印文件</translation>
    </message>
</context>
<context>
    <name>CmdLineParser</name>
    <message>
        <source>Usage: assistant [Options]

-collectionFile file       Uses the specified collection
                           file instead of the default one
-showUrl url               Shows the document with the
                           url.
-enableRemoteControl       Enables Assistant to be
                           remotely controlled.
-show widget               Shows the specified dockwidget
                           which can be &quot;contents&quot;, &quot;index&quot;,
                           &quot;bookmarks&quot; or &quot;search&quot;.
-activate widget           Activates the specified dockwidget
                           which can be &quot;contents&quot;, &quot;index&quot;,
                           &quot;bookmarks&quot; or &quot;search&quot;.
-hide widget               Hides the specified dockwidget
                           which can be &quot;contents&quot;, &quot;index&quot;
                           &quot;bookmarks&quot; or &quot;search&quot;.
-register helpFile         Registers the specified help file
                           (.qch) in the given collection
                           file.
-unregister helpFile       Unregisters the specified help file
                           (.qch) from the give collection
                           file.
-setCurrentFilter filter   Set the filter as the active filter.
-remove-search-index       Removes the full text search index.
-rebuild-search-index      Obsolete. Use -remove-search-index instead.
                           Removes the full text search index.
                           It will be rebuilt on next Assistant run.
-quiet                     Does not display any error or
                           status message.
-help                      Displays this help.
</source>
        <translation>用法：assistant [選項]

-collectionFile 檔案  使用指定的集合檔案
                                       取代預設集合檔案
-showUrl url               顯示 URL 的文件
-enableRemoteControl       啟用以讓 Assistant 能被
                           遠端控制
-show 元件    顯示指定的 Dock 元件，其可為
                           &quot;contents&quot;, &quot;index&quot;
                           &quot;bookmarks&quot; 或 &quot;search&quot;。
-activate 元件    啟用指定的 Dock 元件，其可為
                           &quot;contents&quot;, &quot;index&quot;
                           &quot;bookmarks&quot; 或 &quot;search&quot;。
-hide 元件      隱藏指定的 Dock 元件，其可為
                           &quot;contents&quot;, &quot;index&quot;
                           &quot;bookmarks&quot; 或 &quot;search&quot;。
-register 說明檔案     從指定的集合檔案中註冊指定的
                                            說明檔案 (.qch)
-unregister 說明檔案  從指定的集合檔案中解除註冊
                                             指定的說明檔案 (.qch)
-setCurrentFilter 過濾器   將 &lt;過濾器&gt; 設定為使用中過濾器。
-remove-search-index       移除全文搜尋索引。
-rebuild-search-index      已廢棄選項。改用 -remove-search-index。
                           移除全文搜尋索引。其將
                           於下次開啟 Assistant 時重新建立。
-quiet                     不顯示任何狀態與錯誤訊息。
-help                      顯示此說明。
</translation>
    </message>
    <message>
        <source>Unknown option: %1</source>
        <translation>未知的選項：%1</translation>
    </message>
    <message>
        <source>The collection file &apos;%1&apos; does not exist.</source>
        <translation>集合檔案「%1」不存在。</translation>
    </message>
    <message>
        <source>Missing collection file.</source>
        <translation>遺失集合檔案。</translation>
    </message>
    <message>
        <source>Invalid URL &apos;%1&apos;.</source>
        <translation>無效網址「%1」。</translation>
    </message>
    <message>
        <source>Missing URL.</source>
        <translation>遺失網址。</translation>
    </message>
    <message>
        <source>Unknown widget: %1</source>
        <translation>未知的元件：%1</translation>
    </message>
    <message>
        <source>Missing widget.</source>
        <translation>遺失元件。</translation>
    </message>
    <message>
        <source>The Qt help file &apos;%1&apos; does not exist.</source>
        <translation>Qt 說明檔案「%1」不存在。</translation>
    </message>
    <message>
        <source>Missing help file.</source>
        <translation>遺失說明檔案。</translation>
    </message>
    <message>
        <source>Missing filter argument.</source>
        <translation>遺失過濾器參數。</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>注意</translation>
    </message>
</context>
<context>
    <name>ContentWindow</name>
    <message>
        <source>Open Link</source>
        <translation>開啟連結</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation>在新分頁開啟連結</translation>
    </message>
</context>
<context>
    <name>FilterNameDialogClass</name>
    <message>
        <source>Add Filter Name</source>
        <translation>新增過濾器名稱</translation>
    </message>
    <message>
        <source>Filter Name:</source>
        <translation>過濾器名稱：</translation>
    </message>
    <message>
        <source>Add Filter</source>
        <translation>新增過濾器</translation>
    </message>
</context>
<context>
    <name>FindWidget</name>
    <message>
        <source>Previous</source>
        <translation>前一個</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一個</translation>
    </message>
    <message>
        <source>Case Sensitive</source>
        <translation>區分大小寫</translation>
    </message>
    <message>
        <source>&lt;img src=&quot;:/qt-project.org/assistant/images/wrap.png&quot;&gt;&amp;nbsp;Search wrapped</source>
        <translation>&lt;img src=&quot;:/qt-project.org/assistant/images/wrap.png&quot;&gt;&amp;nbsp;環繞搜尋</translation>
    </message>
</context>
<context>
    <name>FontPanel</name>
    <message>
        <source>Font</source>
        <translation>字型</translation>
    </message>
    <message>
        <source>&amp;Writing system</source>
        <translation>手寫系統(&amp;W)</translation>
    </message>
    <message>
        <source>&amp;Family</source>
        <translation>家族(&amp;W)</translation>
    </message>
    <message>
        <source>&amp;Style</source>
        <translation>樣式(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Point size</source>
        <translation>點大小(&amp;P)</translation>
    </message>
</context>
<context>
    <name>GlobalActions</name>
    <message>
        <source>&amp;Back</source>
        <translation>返回(&amp;B)</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>往前(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Home</source>
        <translation>首頁(&amp;H)</translation>
    </message>
    <message>
        <source>ALT+Home</source>
        <translation>ALT+Home</translation>
    </message>
    <message>
        <source>Zoom &amp;in</source>
        <translation>放大(&amp;I)</translation>
    </message>
    <message>
        <source>Zoom &amp;out</source>
        <translation>縮小(&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Copy selected Text</source>
        <translation>複製選取文字(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>列印(&amp;P)...</translation>
    </message>
    <message>
        <source>&amp;Find in Text...</source>
        <translation>在文字中尋找(&amp;F)...</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>尋找(&amp;F)</translation>
    </message>
</context>
<context>
    <name>HelpEngineWrapper</name>
    <message>
        <source>Unfiltered</source>
        <translation>未過濾</translation>
    </message>
</context>
<context>
    <name>HelpViewer</name>
    <message>
        <source>Error 404...</source>
        <translation>錯誤 404…</translation>
    </message>
    <message>
        <source>The page could not be found</source>
        <translation>找不到此頁面</translation>
    </message>
    <message>
        <source>Please make sure that you have all documentation sets installed.</source>
        <translation>確保您已經安裝所有的文件組合。</translation>
    </message>
    <message>
        <source>Error loading: %1</source>
        <translation>載入時發生問題：%1</translation>
    </message>
    <message>
        <source>&lt;title&gt;about:blank&lt;/title&gt;</source>
        <translation>&lt;title&gt;about:blank&lt;/title&gt;</translation>
    </message>
    <message>
        <source>&lt;title&gt;Error 404...&lt;/title&gt;&lt;div align=&quot;center&quot;&gt;&lt;br&gt;&lt;br&gt;&lt;h1&gt;The page could not be found.&lt;/h1&gt;&lt;br&gt;&lt;h3&gt;&apos;%1&apos;&lt;/h3&gt;&lt;/div&gt;</source>
        <translation>&lt;title&gt;錯誤 404...&lt;/title&gt;&lt;div align=&quot;center&quot;&gt;&lt;br&gt;&lt;br&gt;&lt;h1&gt;找不到頁面。&lt;/h1&gt;&lt;br&gt;&lt;h3&gt;「%1」&lt;/h3&gt;&lt;/div&gt;</translation>
    </message>
    <message>
        <source>Open Link</source>
        <translation>開啟連結</translation>
    </message>
    <message>
        <source>Open Link in New Tab	Ctrl+LMB</source>
        <translation>在新分頁開啟連結	Ctrl+滑鼠左鍵</translation>
    </message>
    <message>
        <source>Copy &amp;Link Location</source>
        <translation>複製連結位置(&amp;L)</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>重新載入</translation>
    </message>
    <message>
        <source>Open Link in New Page</source>
        <translation>在新頁面打開連結</translation>
    </message>
</context>
<context>
    <name>IndexWindow</name>
    <message>
        <source>&amp;Look for:</source>
        <translation>搜尋(&amp;L)：</translation>
    </message>
    <message>
        <source>Open Link</source>
        <translation>開啟連結</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation>在新分頁開啟連結</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Index</source>
        <translation>索引</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>內容</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>書籤</translation>
    </message>
    <message>
        <source>Open Pages</source>
        <translation>開啟頁面</translation>
    </message>
    <message>
        <source>Qt Assistant</source>
        <translation>Qt 小幫手</translation>
    </message>
    <message>
        <source>Bookmark Toolbar</source>
        <translation>書籤工具列</translation>
    </message>
    <message>
        <source>Looking for Qt Documentation...</source>
        <translation>搜尋 Qt 文件中...</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>檔案(&amp;F)</translation>
    </message>
    <message>
        <source>New &amp;Tab</source>
        <translation>新增分頁(&amp;T)</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>關閉分頁(&amp;C)</translation>
    </message>
    <message>
        <source>Page Set&amp;up...</source>
        <translation>頁面設定(&amp;U)...</translation>
    </message>
    <message>
        <source>Print Preview...</source>
        <translation>列印預覽...</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>離開(&amp;X)</translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation>CTRL+Q</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>離開(&amp;Q)</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>編輯(&amp;E)</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>尋找下一筆(&amp;N)</translation>
    </message>
    <message>
        <source>Find &amp;Previous</source>
        <translation>尋找前一筆(&amp;P)</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>偏好設定...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>檢視(&amp;V)</translation>
    </message>
    <message>
        <source>Normal &amp;Size</source>
        <translation>一般大小(&amp;S)</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>ALT+C</source>
        <translation>ALT+C</translation>
    </message>
    <message>
        <source>ALT+I</source>
        <translation>ALT+I</translation>
    </message>
    <message>
        <source>ALT+O</source>
        <translation>ALT+O</translation>
    </message>
    <message>
        <source>ALT+S</source>
        <translation>ALT+S</translation>
    </message>
    <message>
        <source>ALT+P</source>
        <translation>ALT+P</translation>
    </message>
    <message>
        <source>&amp;Go</source>
        <translation>前往(&amp;G)</translation>
    </message>
    <message>
        <source>Sync with Table of Contents</source>
        <translation>與目錄同步</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>同步</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>下一頁</translation>
    </message>
    <message>
        <source>Ctrl+Alt+Right</source>
        <translation>Ctrl+Alt+Right</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>前一頁</translation>
    </message>
    <message>
        <source>Ctrl+Alt+Left</source>
        <translation>Ctrl+Alt+Left</translation>
    </message>
    <message>
        <source>&amp;Bookmarks</source>
        <translation>書籤(&amp;B)</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>說明(&amp;H)</translation>
    </message>
    <message>
        <source>About...</source>
        <translation>關於...</translation>
    </message>
    <message>
        <source>Navigation Toolbar</source>
        <translation>導覽工具列</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>視窗(&amp;W)</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation>縮放</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>最小化</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Toolbars</source>
        <translation>工具列</translation>
    </message>
    <message>
        <source>Filter Toolbar</source>
        <translation>過濾器工具列</translation>
    </message>
    <message>
        <source>Filtered by:</source>
        <translation>已過濾：</translation>
    </message>
    <message>
        <source>Address Toolbar</source>
        <translation>位址工具列</translation>
    </message>
    <message>
        <source>Address:</source>
        <translation>位址：</translation>
    </message>
    <message>
        <source>Could not find the associated content item.</source>
        <translation>找不到相關的內容項目。</translation>
    </message>
    <message>
        <source>&lt;center&gt;&lt;h3&gt;%1&lt;/h3&gt;&lt;p&gt;Version %2&lt;/p&gt;&lt;p&gt;Browser: %3&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Copyright (C) %4 The Qt Company Ltd.&lt;/p&gt;</source>
        <translation>&lt;center&gt;&lt;h3&gt;%1&lt;/h3&gt;&lt;p&gt;版本 %2&lt;/p&gt;&lt;p&gt;瀏覽器：%3&lt;/p&gt;&lt;/center&gt;&lt;p&gt;版權所有 %4 Qt 公司&lt;/p&gt;</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>關於 %1</translation>
    </message>
    <message>
        <source>Updating search index</source>
        <translation>更新搜尋索引</translation>
    </message>
    <message>
        <source>Could not register file &apos;%1&apos;: %2</source>
        <translation>無法註冊檔案「%1」：%2</translation>
    </message>
    <message>
        <source>Unfiltered</source>
        <translation>未經篩選</translation>
    </message>
</context>
<context>
    <name>OpenPagesWidget</name>
    <message>
        <source>Close %1</source>
        <translation>關閉 %1</translation>
    </message>
    <message>
        <source>Close All Except %1</source>
        <translation>關閉除了 %1 的所有分頁</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Add Documentation</source>
        <translation>新增文件</translation>
    </message>
    <message>
        <source>Qt Compressed Help Files (*.qch)</source>
        <translation>Qt 壓縮說明檔(*.qch)</translation>
    </message>
    <message>
        <source>The namespace %1 is already registered!</source>
        <translation>命名空間 %1 已註冊！</translation>
    </message>
    <message>
        <source>The specified file is not a valid Qt Help File!</source>
        <translation>指定的檔案不是合法的 Qt 說明檔！</translation>
    </message>
    <message>
        <source>Remove Documentation</source>
        <translation>移除文件</translation>
    </message>
    <message>
        <source>Some documents currently opened in Assistant reference the documentation you are attempting to remove. Removing the documentation will close those documents.</source>
        <translation>部份有參考您嘗試移除文件的文件目前已在 Assistant 中開啟。移除此文件也將關閉那些文件。</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>確定</translation>
    </message>
    <message>
        <source>Use custom settings</source>
        <translation>使用自訂設定</translation>
    </message>
    <message>
        <source>No Component</source>
        <translation>沒有元件</translation>
    </message>
    <message>
        <source>Invalid Component</source>
        <translation>元件無效</translation>
    </message>
    <message>
        <source>No Version</source>
        <translation>沒有版本</translation>
    </message>
    <message>
        <source>Invalid Version</source>
        <translation>版本無效</translation>
    </message>
    <message>
        <source>Filter Exists</source>
        <translation>篩選器存在</translation>
    </message>
    <message>
        <source>The filter &quot;%1&quot; already exists.</source>
        <translation>篩選器「%1」已存在。</translation>
    </message>
    <message>
        <source>Add Filter</source>
        <translation>新增篩選器</translation>
    </message>
    <message>
        <source>New Filter</source>
        <translation>新篩選器</translation>
    </message>
    <message>
        <source>Rename Filter</source>
        <translation>重命名篩選器</translation>
    </message>
    <message>
        <source>Remove Filter</source>
        <translation>移除篩選器</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the &quot;%1&quot; filter?</source>
        <translation>確定移除「%1」篩選器？</translation>
    </message>
</context>
<context>
    <name>PreferencesDialogClass</name>
    <message>
        <source>Preferences</source>
        <translation>偏好設定</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>字型</translation>
    </message>
    <message>
        <source>Font settings:</source>
        <translation>字型設定：</translation>
    </message>
    <message>
        <source>Browser</source>
        <translation>瀏覽器</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>應用程式</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>過濾器</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>過濾：</translation>
    </message>
    <message>
        <source>Attributes:</source>
        <translation>屬性：</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>新增</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>文件</translation>
    </message>
    <message>
        <source>Registered Documentation:</source>
        <translation>已註冊文件：</translation>
    </message>
    <message>
        <source>&lt;Filter&gt;</source>
        <translation>&lt;過濾器&gt;</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation>新增...</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>選項</translation>
    </message>
    <message>
        <source>On help start:</source>
        <translation>於說明開始：</translation>
    </message>
    <message>
        <source>Show my home page</source>
        <translation>顯示我的首頁</translation>
    </message>
    <message>
        <source>Show a blank page</source>
        <translation>顯示空白頁面</translation>
    </message>
    <message>
        <source>Show my tabs from last session</source>
        <translation>顯示我上次工作階段的分頁</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>首頁</translation>
    </message>
    <message>
        <source>Current Page</source>
        <translation>目前頁面</translation>
    </message>
    <message>
        <source>Blank Page</source>
        <translation>空白頁面</translation>
    </message>
    <message>
        <source>Restore to default</source>
        <translation>回復為預設值</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>外觀</translation>
    </message>
    <message>
        <source>Show tabs for each individual page</source>
        <translation>顯示每個個別頁面的分頁</translation>
    </message>
    <message>
        <source>Components:</source>
        <translation>元件：</translation>
    </message>
    <message>
        <source>Versions:</source>
        <translation>版本：</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>重命名…</translation>
    </message>
</context>
<context>
    <name>RemoteControl</name>
    <message>
        <source>Debugging Remote Control</source>
        <translation>遠端除錯控制</translation>
    </message>
    <message>
        <source>Received Command: %1 %2</source>
        <translation>已接收指令：%1 %2</translation>
    </message>
</context>
<context>
    <name>SearchWidget</name>
    <message>
        <source>&amp;Copy</source>
        <translation>複製(&amp;C)</translation>
    </message>
    <message>
        <source>Copy &amp;Link Location</source>
        <translation>複製連結位置(&amp;L)</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation>在新分頁開啟連結</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>全部選取</translation>
    </message>
</context>
<context>
    <name>TabBar</name>
    <message>
        <source>(Untitled)</source>
        <translation>（未命名）</translation>
    </message>
    <message>
        <source>New &amp;Tab</source>
        <translation>新增分頁(&amp;T)</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>關閉分頁(&amp;C)</translation>
    </message>
    <message>
        <source>Close Other Tabs</source>
        <translation>關閉其他分頁</translation>
    </message>
    <message>
        <source>Add Bookmark for this Page...</source>
        <translation>將此頁面新增到書籤…</translation>
    </message>
</context>
<context>
    <name>TopicChooser</name>
    <message>
        <source>Choose Topic</source>
        <translation>選擇標題</translation>
    </message>
    <message>
        <source>&amp;Topics</source>
        <translation>標題(&amp;T)</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>顯示(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>關閉(&amp;C)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>篩選器</translation>
    </message>
    <message>
        <source>Choose a topic for &lt;b&gt;%1&lt;/b&gt;:</source>
        <translation>選擇 %1 的標題：</translation>
    </message>
</context>
<context>
    <name>OptionsWidget</name>
    <message>
        <source>No Option</source>
        <translation>無選項</translation>
    </message>
    <message>
        <source>Invalid Option</source>
        <translation>選項無效</translation>
    </message>
</context>
</TS>
